import { ElementType, ReactElement, createElement as CreateElement } from 'react';
import { Registry } from './Registry';
import { XmlRendererProps } from './GenericRenderer';
/**
 * The output of a ReactRenderer rule should be a React element (eg. `<p>` or `<P>`), a string, or `null`.
 */
export declare type XmlRendererReactOutput = ReactElement<any, any> | string | null;
/**
 * The props that are passed to every component rendered by ReactRenderer. These include the `node` and `traverse`
 * props, so that you can query and travel further into the render loop, but also `key` for your convenience, because
 * most output is actually an array of results mapped from XML nodes.
 */
export declare type XmlRendererReactProps = XmlRendererProps<XmlRendererReactOutput> & {
    key: string;
};
/**
 * The thing that you give to {@link ReactRenderer.add} should be a React component class or function component. It is
 * given two props by xml-renderer automatically, `node` and `traverse`; see also {@link XmlRendererReactProps}.
 */
/**
 *
 * This is the React-specific sibling of {@link GenericRenderer}.
 */
export declare class ReactRenderer<P extends {} = {}> extends Registry<ElementType<XmlRendererReactProps & P>> {
    render(createElement: typeof CreateElement, node: Node, additionalProps?: P): XmlRendererReactOutput;
}
